@@ -43,6 +43,8 @@ class Config:
 
     # Extension
     extension_deploy_class = None
+    extension_username = None
+    extension_password = None
 
     # Config file instance
     config_file = None
@@ -55,6 +57,7 @@ class Config:
         self._set_api_config()
         self._set_communicator_config()
         self._set_changelog_config()
+        self._set_extension()
 
     # Method for mock tests
     def get_config_file(self):
@@ -90,6 +93,8 @@ class Config:
 
     def _set_extension(self):
         self.extension_deploy_class = self._get_property('EXTENSION', 'deploy_class', None)
+        self.extension_username = self._get_property('EXTENSION', 'username', None)
+        self.extension_password = self._get_property('EXTENSION', 'password', None)
 
     def _get_config_or_environment(self, group, api_config, os_environment, default_value):
         try:
