@@ -5,7 +5,6 @@ from subprocess import check_call
 
 from gitflow_api.deploy.deploy import Deploy
 
-
 class Pypi(Deploy):
 
     def __init__(self):
@@ -23,5 +22,6 @@ class Pypi(Deploy):
         cmd = 'python3 setup.py sdist'
         check_call(cmd, shell=True)
 
-        cmd = 'twine upload dist/*'
-        check_call(cmd, shell=True)
+        cmd = 'twine upload --username {username} --password {password} dist/* '.format(
+            username=self.config.extension_username, password=self.config.extension_password)
+        check_call(cmd, shell=True)
\ No newline at end of file
